@@ -32,10 +32,15 @@ def main():
     if args.fix_edges:
         runner.Runner.fix_edges(metadata, args)
     else:
+        print(metadata)
+        print(args)
         r = runner.Runner.from_command_line(metadata, args)
-        if args.upgrade:
-            r.upgrade()
-        elif args.downgrade is not None:
-            r.downgrade(args.downgrade)
-        else:
-            r.run()
+
+
+s print(r)
+   if args.upgrade:
+        r.upgrade()
+    elif args.downgrade is not None:
+        r.downgrade(args.downgrade)
+    else:
+        r.run()
